@@ -22,25 +22,21 @@ from nise.generators.azure.azure_generator import AzureGenerator
 class SQLGenerator(AzureGenerator):
     """Generator for SQL Database data."""
 
-    SERVICE_METER = (
-        ('SQL DB Single Std', 'Single Standard', 'S0 DTUs - Free', ''),
-    )
+    SERVICE_METER = (("SQL DB Single Std", "Single Standard", "S0 DTUs - Free", ""),)
     SERVICE_INFO_2 = [None]
     EXAMPLE_RESOURCE = (
-        ('RG1', 'mysa1'),
-        ('RG1', 'costmgmtacct1234'),
-        ('RG2', 'mysa1'),
-        ('RG2', 'costmgmtacct1234'),
-        ('costmgmt', 'mysa1'),
-        ('costmgmt', 'costmgmtacct1234'),
-        ('hccm', 'mysa1'),
-        ('hccm', 'costmgmtacct1234')
-    )
-    ADDITIONAL_INFO = (
-        {'ConsumptionMeter': '22222222-3333-4444-5555-666666666666'},
+        ("RG1", "mysa1"),
+        ("RG1", "costmgmtacct1234"),
+        ("RG2", "mysa1"),
+        ("RG2", "costmgmtacct1234"),
+        ("costmgmt", "mysa1"),
+        ("costmgmt", "costmgmtacct1234"),
+        ("hccm", "mysa1"),
+        ("hccm", "costmgmtacct1234"),
     )
+    ADDITIONAL_INFO = ({"ConsumptionMeter": "22222222-3333-4444-5555-666666666666"},)
 
     def __init__(self, start_date, end_date, payer_account, usage_accounts, attributes=None):
         """Initialize the data transfer generator."""
-        self._service_name = 'SQL Database'
+        self._service_name = "SQL Database"
         super().__init__(start_date, end_date, payer_account, usage_accounts, attributes)
