@@ -15,6 +15,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Defines the upload mechanism to various clouds."""
+import logging
 import os
 import sys
 import traceback
@@ -24,9 +25,12 @@ from azure.storage.blob import BlobServiceClient
 from botocore.exceptions import ClientError
 from google.cloud import storage
 from google.cloud.exceptions import GoogleCloudError
-from msrestazure.azure_exceptions import ClientException, CloudError
+from msrestazure.azure_exceptions import ClientException
+from msrestazure.azure_exceptions import CloudError
 from requests.exceptions import ConnectionError as BotoConnectionError
 
+LOG = logging.getLogger(__name__)
+
 
 def upload_to_s3(bucket_name, bucket_file_path, local_path):
     """Upload data to an S3 bucket.
@@ -41,15 +45,12 @@ def upload_to_s3(bucket_name, bucket_file_path, local_path):
     """
     uploaded = True
     try:
-        s3_client = boto3.resource('s3')
-        s3_client.Bucket(bucket_name).upload_file(local_path,  # pylint: disable=maybe-no-member
-                                                  bucket_file_path)
-        msg = 'Uploaded {} to s3 bucket {}.'.format(
-            bucket_file_path, bucket_name)
-        print(msg)
-    except (ClientError, BotoConnectionError,
-            boto3.exceptions.S3UploadFailedError) as upload_err:
-        print(upload_err)
+        s3_client = boto3.resource("s3")
+        s3_client.Bucket(bucket_name).upload_file(local_path, bucket_file_path)  # pylint: disable=maybe-no-member
+        msg = f"Uploaded {bucket_file_path} to s3 bucket {bucket_name}."
+        LOG.info(msg)
+    except (ClientError, BotoConnectionError, boto3.exceptions.S3UploadFailedError) as upload_err:
+        LOG.error(upload_err)
         uploaded = False
     return uploaded
 
@@ -68,16 +69,14 @@ def upload_to_azure_container(storage_file_name, local_path, storage_file_path):
     """
     try:
         # Retrieve the connection string for use with the application.
-        connect_str = os.getenv('AZURE_STORAGE_CONNECTION_STRING')
+        connect_str = os.getenv("AZURE_STORAGE_CONNECTION_STRING")
         blob_service_client = BlobServiceClient.from_connection_string(connect_str)
-        blob_client = blob_service_client.get_blob_client(
-            container=storage_file_name, blob=storage_file_path
-        )
-        with open(local_path, 'rb') as data:
+        blob_client = blob_service_client.get_blob_client(container=storage_file_name, blob=storage_file_path)
+        with open(local_path, "rb") as data:
             blob_client.upload_blob(data=data)
-        print(f'uploaded {storage_file_name} to {storage_file_path}')
+        LOG.info(f"uploaded {storage_file_name} to {storage_file_path}")
     except (CloudError, ClientException, IOError) as error:
-        print(error)
+        LOG.error(error)
         traceback.print_exc(file=sys.stderr)
         return False
     return True
@@ -98,10 +97,12 @@ def upload_to_gcp_storage(bucket_name, source_file_name, destination_blob_name):
     """
     uploaded = True
 
-    if 'GOOGLE_APPLICATION_CREDENTIALS' not in os.environ:
-        print('Please set your GOOGLE_APPLICATION_CREDENTIALS '
-              'environment variable before attempting to load file into'
-              'GCP Storage.')
+    if "GOOGLE_APPLICATION_CREDENTIALS" not in os.environ:
+        LOG.warning(
+            "Please set your GOOGLE_APPLICATION_CREDENTIALS "
+            "environment variable before attempting to load file into"
+            "GCP Storage."
+        )
         return False
     try:
         storage_client = storage.Client()
@@ -111,9 +112,8 @@ def upload_to_gcp_storage(bucket_name, source_file_name, destination_blob_name):
 
         blob.upload_from_filename(source_file_name)
 
-        print('File {} uploaded to GCP Storage {}.'.format(source_file_name,
-                                                           destination_blob_name))
+        LOG.info(f"File {source_file_name} uploaded to GCP Storage {destination_blob_name}.")
     except GoogleCloudError as upload_err:
-        print(upload_err)
+        LOG.error(upload_err)
         uploaded = False
     return uploaded
